class Ftgl < Formula
  desc "Freetype / OpenGL bridge"
  homepage "https://sourceforge.net/projects/ftgl/"
  url "https://downloads.sourceforge.net/project/ftgl/FTGL%20Source/2.1.3~rc5/ftgl-2.1.3-rc5.tar.gz"
  sha256 "5458d62122454869572d39f8aa85745fc05d5518001bcefa63bd6cbb8d26565b"
  license "MIT"

  livecheck do
    url :stable
    regex(%r{url=.*?/ftgl[._-]v?(\d+(?:\.\d+)+(?:-rc\d*)?)\.t}i)
  end

  depends_on "pkg-config" => :test
  depends_on "freetype"

  on_linux do
    depends_on "mesa"
    depends_on "mesa-glu"
  end

  # build patch to fix type mismatch
  patch :DATA

  def install
    # If doxygen is installed, the docs may still fail to build.
    # So we disable building docs.
    inreplace "configure", "set dummy doxygen;", "set dummy no_doxygen;"

    # Skip building the example program by failing to find GLUT (MacPorts)
    # by setting --with-glut-inc and --with-glut-lib
    args = %w[
      --disable-freetypetest
      --with-glut-inc=/dev/null
      --with-glut-lib=/dev/null
    ]

    args << "--with-gl-inc=#{Formula["mesa-glu"].opt_include}" if OS.linux?

    system "./configure", *args, *std_configure_args

    system "make", "install"
  end

  test do
    (testpath/"test.c").write <<~EOS
      #include <FTGL/ftgl.h>
      #include <stdio.h>

      int main() {
        FTGLfont *font = ftglCreatePixmapFont(NULL);

        ftglSetFontFaceSize(font, 72, 72);

        ftglDestroyFont(font);
        printf("Font object created and destroyed successfully.\\n");

        return 0;
      }
    EOS

    pkg_config_flags = shell_output("pkg-config --cflags --libs ftgl").chomp.split
    system ENV.cc, "test.c", "-o", "test", *pkg_config_flags
    system "./test"
  end
end

__END__
diff --git a/src/FTVectoriser.cpp b/src/FTVectoriser.cpp
index ea5c571..e0c4e2d 100644
--- a/src/FTVectoriser.cpp
+++ b/src/FTVectoriser.cpp
@@ -166,7 +166,7 @@ void FTVectoriser::ProcessContours()
     for(int i = 0; i < ftContourCount; ++i)
     {
         FT_Vector* pointList = &outline.points[startIndex];
-        char* tagList = &outline.tags[startIndex];
+        char* tagList = reinterpret_cast<char*>(&outline.tags[startIndex]);

         endIndex = outline.contours[i];
         contourLength =  (endIndex - startIndex) + 1;
